@@ -5,7 +5,7 @@ extern crate ndarray;
 extern crate ndarray_rand;
 extern crate test;
 
-use rand::distributions::Range;
+use rand::distributions::Uniform;
 use rand::distributions::Normal;
 use ndarray::Array;
 use ndarray_rand::RandomExt;
@@ -13,6 +13,15 @@ use ndarray_rand::F32;
 
 use test::Bencher;
 
+#[bench]
+fn uniform_f32(b: &mut Bencher) {
+    let m = 100;
+    b.iter(|| {
+        let a = Array::random((m, m), Uniform::new(-1f32, 1.));
+        a
+    });
+}
+
 #[bench]
 fn norm_f32(b: &mut Bencher) {
     let m = 100;
@@ -26,7 +35,7 @@ fn norm_f32(b: &mut Bencher) {
 fn norm_f64(b: &mut Bencher) {
     let m = 100;
     b.iter(|| {
-        let a = Array::random((m, m), (Normal::new(0., 1.)));
+        let a = Array::random((m, m), Normal::new(0., 1.));
         a
     });
 }
